.. toctree::
   :maxdepth: 2

Agent-side MIB implementations
------------------------------

.. include:: /../../examples/v1arch/asyncio/agent/cmdrsp/implementing-scalar-mib-objects-over-ipv4-and-ipv6.py
   :start-after: """
   :end-before: """  #

.. literalinclude:: /../../examples/v1arch/asyncio/agent/cmdrsp/implementing-scalar-mib-objects-over-ipv4-and-ipv6.py
   :start-after: """  #
   :language: python

:download:`Download</../../examples/v1arch/asyncio/agent/cmdrsp/implementing-scalar-mib-objects-over-ipv4-and-ipv6.py>` script.


See also: :doc:`library reference </docs/api-reference>`.
